Crate xmodmap_pke[−][src]
Functions
| xmodmap_pke | Return HashMap with KeyCode as key and vector of KeySyms as value
(This block of code was taken from original |
Type Definitions
| XmodmapPke |
| xmodmap_pke | Return HashMap with KeyCode as key and vector of KeySyms as value
(This block of code was taken from original |
| XmodmapPke |